pub struct SurbRingBuffer<S>(Arc<Mutex<AllocRingBuffer<(HoprSurbId, S)>>>);Expand description
Ring buffer containing SURBs along with their IDs.
All these SURBs usually belong to the same pseudonym and are therefore identified
only by the [HoprSurbId].
Tuple Fields
0: Arc<Mutex<AllocRingBuffer<(HoprSurbId, S)>>>Implementations
Sourceimpl<S> SurbRingBuffer<S>
impl<S> SurbRingBuffer<S>
pub fn new(capacity: usize) -> Self
Sourcepub fn push<I: IntoIterator<Item = (HoprSurbId, S)>>(&self, surbs: I) -> usize
pub fn push<I: IntoIterator<Item = (HoprSurbId, S)>>(&self, surbs: I) -> usize
Push all SURBs with their IDs into the RB.
Returns the total number of elements in the RB after the push.
Sourcepub fn pop_one(&self) -> Option<PoppedSurb<S>>
pub fn pop_one(&self) -> Option<PoppedSurb<S>>
Pop the latest SURB and its IDs from the RB.
Sourcepub fn pop_one_if_has_id(&self, id: &HoprSurbId) -> Option<PoppedSurb<S>>
pub fn pop_one_if_has_id(&self, id: &HoprSurbId) -> Option<PoppedSurb<S>>
Check if the next SURB has the given ID and pop it from the RB.